pub(crate) async fn balances(
__arg0: State<Arc<InternalState>>,
) -> impl IntoResponseExpand description
Get node’s and associated Safe’s HOPR and native balances as the allowance for HOPR tokens to be drawn by HoprChannels from Safe.
HOPR tokens from the Safe balance are used to fund the payment channels between this node and other nodes on the network. NATIVE balance of the Node is used to pay for the gas fees for the blockchain.